==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/da_DK.php <==
<?php
$lang['friendlyname'] = 'Fil-h&aring;ndtering';
$lang['permission'] = 'Adgang til brug af Fil-h&aring;ndterings modulet';
$lang['permissionadvanced'] = 'Adgang til avanceretbrug af Fil-h&aring;ndterings modulet';
$lang['moddescription'] = 'H&aring;ndtering af filer og mapper i upload-sektionen af din cmsms installation';
$lang['installed'] = 'Fil-h&aring;ndtering modulet version %s blev installeret';
$lang['postinstall'] = 'Fil-h&aring;ndtering modulet blev installeret';
$lang['uninstalled'] = 'Fil-h&aring;ndtering modulete blev afinstalleret';
$lang['really_uninstall'] = 'Er du sikker p&aring; du vil afinstalleret FileManager modulet?';
$lang['upgraded'] = 'Fil-h&aring;ndtering modulet blev opgraderet til version %s';
$lang['fileview'] = 'Fil-visning';
$lang['switchtofileview'] = 'Skift til fil-visning';
$lang['settings'] = 'Indstillinger';
$lang['savesettings'] = 'Gem indstillinger';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Fil-info';
$lang['fileowner'] = 'Ejer';
$lang['fileperms'] = 'Rettigheder';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['delete'] = 'Slet';
$lang['notwritable'] = 'Skrivebeskyttet';
$lang['filetoobig'] = 'er for stor. Upload blev afbrudt.';
$lang['unknown'] = 'Ukendt';
$lang['fileoutsideuploads'] = 'Du m&aring; ikke &aelig;ndre i filer udenfor uploads-mappen! (Dette kr&aelig;ver avanceret fil-h&aring;ndterings tilladelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'File nr.';
$lang['subdirs'] = 'undermapper';
$lang['subdir'] = 'undermappe';
$lang['and'] = 'og';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; mappen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen og alt dens indhold blev slettet.';
$lang['dirtreedeletefail'] = 'Der skete en fejl under sletning af mappen. Noget af indholdet kan v&aelig;re blevet slettet.';
$lang['singlefiledeletesuccess'] = 'Filen blev slettet';
$lang['filedeletesuccess'] = 'blev slettet.';
$lang['singlefiledeletefail'] = 'Sletning af filen mislykkedes';
$lang['filedeletefail'] = 'blev ikke slettet pga. en fejl.';
$lang['singledirdeletesuccess'] = 'Mappen blev slettet';
$lang['singledirdeletefail'] = 'Der skete en fejl ved sletning af mappen.';
$lang['deleteselected'] = 'Slet de valgte filer';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; de valgte filer skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletning af filer blev afbrudt';
$lang['recursetext'] = 'Medtag undermapper';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['moveselected'] = 'Flyt de valgte filer';
$lang['copyselected'] = 'Kopi&eacute;r de valgte filer';
$lang['selecttargetdir'] = 'V&aelig;lg hvor der skal flyttes/kopieres til';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopieret til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['rename'] = 'Omd&oslash;b';
$lang['newname'] = 'Nyt navn:';
$lang['renamesuccess'] = 'Filen blev omd&oslash;bt';
$lang['renamefailure'] = 'Omd&oslash;bning af filen fejlede';
$lang['renamecancelled'] = 'Omd&oslash;bning afbrudt';
$lang['owner'] = 'Ejer';
$lang['group'] = 'Gruppe';
$lang['others'] = 'Andre';
$lang['newpermissions'] = 'Nye tilladelser:';
$lang['setpermissions'] = 'S&aelig;t tilladelser';
$lang['permissionstyle'] = 'Tilladelses-stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Hurtig chmod (som 777)';
$lang['chmod'] = 'Skift tilladelser';
$lang['chmodselected'] = 'Skift tilladelser p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fik nye tilladelser';
$lang['chmodfailure'] = '&AElig;ndring af filens tilladelser fejlede';
$lang['chmodcancelled'] = '&AElig;ndring af tilladelser blev afbrudt';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, someof it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'Mappen fik nye tilladelser';
$lang['dirchmodfailure'] = '&AElig;ndring af mappens tilladelser fejlede';
$lang['dirnotemptyconfirm'] = 'Mappen er ikke tom! Er du sikker p&aring; du vil slette den og alt dens indhold?';
$lang['dirtreedeletecancelled'] = 'Sletning af mappen blev afbrudt';
$lang['imsure'] = 'Jeg er sikker';
$lang['cancel'] = 'Fortryd';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Upload ny fil:';
$lang['unpackafterupload'] = 'Fors&oslash;g udpakning efter upload (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'blev korrekt uploadet';
$lang['uploadfail'] = 'blev ikke korrekt upload&#039;et pga. en fejl';
$lang['unpacksuccess'] = 'blev korrekt udpakket';
$lang['unpackfail'] = 'blev ikke korrekt udpakket pga.:';
$lang['packfileopenfail'] = 'Kunne ikke udpakke filen (ikke-underst&oslash;ttet format?)';
$lang['packfilewritefail'] = 'Kunne ikke f&aring; lov til at skrive til filen &amp;s';
$lang['currentpath'] = 'Nuv&aelig;rende sti:';
$lang['newdirname'] = 'Opret ny mappe:';
$lang['newdirsuccess'] = 'Mappen blev oprettet';
$lang['newdirfail'] = 'Det skete en fejl ved oprettelse af mappen';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Ikon st&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'Tusinde-punkt';
$lang['none'] = 'Ingen';
$lang['showthumbnails'] = 'Vis billedeksempler';
$lang['showthumbnailshelp'] = 'Hvis dette er sl&aring;et til vises billedeksempler hvis de eksisterer og eksempel-filen skjules. Hvis sl&aring;et fra vises alle filer.';
$lang['uploadfilesto'] = 'Upload&#039;er filer til:';
$lang['uploadview'] = 'Upload filer';
$lang['uploadboxes'] = 'Antal upload-bokse';
$lang['nothinguploaded'] = 'Intet blev upload&#039;et';
$lang['unsupportedarchive'] = 'Ikke-underst&oslash;ttet arkiv-format';
$lang['uploadmethod'] = 'Upload metode';
$lang['uploaderstandard'] = 'Standard html input-metode (tillader udpakning)';
$lang['enableadvanced'] = 'Sl&aring; avanceret modus til? (hvis tilladt)';
$lang['advancedhelp'] = 'Giver dig adgang til hele cmsms-filsystemet, ikke bare /upload/ (hvis tilladelsen er sl&aring;et til)';
$lang['showhiddenfileshelp'] = 'Virker kun med avanceret modus sl&aring;et til';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekr&aelig;ft sletning af en enkelt fil?';
$lang['settingssaved'] = 'Indstillinger blev gemt';
$lang['help'] = '		<h3>Hvad g&oslash;r dette modul?</h3>
		<p>Dette modul giver adgang til basale funktioner til filh&aring;ndtering</p>
		<h3>Hvordan bruger jeg det?</h3>
		<p>V&aelig;lg det fra indholds-menuen</p>';
$lang['utma'] = '156861353.2155648126422823700.1234651492.1234651492.1234726049.2';
$lang['utmz'] = '156861353.1234651492.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/da_DK.php <==
<?php
$lang['friendlyname'] = 'Fil-h&aring;ndtering';
$lang['permission'] = 'Adgang til brug af Fil-h&aring;ndterings modulet';
$lang['permissionadvanced'] = 'Adgang til avanceretbrug af Fil-h&aring;ndterings modulet';
$lang['moddescription'] = 'H&aring;ndtering af filer og mapper i upload-sektionen af din cmsms installation';
$lang['installed'] = 'Fil-h&aring;ndtering modulet version %s blev installeret';
$lang['postinstall'] = 'Fil-h&aring;ndtering modulet blev installeret';
$lang['uninstalled'] = 'Fil-h&aring;ndtering modulete blev afinstalleret';
$lang['really_uninstall'] = 'Er du sikker p&aring; du vil afinstalleret FileManager modulet?';
$lang['upgraded'] = 'Fil-h&aring;ndtering modulet blev opgraderet til version %s';
$lang['fileview'] = 'Fil-visning';
$lang['switchtofileview'] = 'Skift til fil-visning';
$lang['settings'] = 'Indstillinger';
$lang['savesettings'] = 'Gem indstillinger';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Fil-info';
$lang['fileowner'] = 'Ejer';
$lang['fileperms'] = 'Rettigheder';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['delete'] = 'Slet';
$lang['notwritable'] = 'Skrivebeskyttet';
$lang['filetoobig'] = 'er for stor. Upload blev afbrudt.';
$lang['unknown'] = 'Ukendt';
$lang['fileoutsideuploads'] = 'Du m&aring; ikke &aelig;ndre i filer udenfor uploads-mappen! (Dette kr&aelig;ver avanceret fil-h&aring;ndterings tilladelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'File nr.';
$lang['subdirs'] = 'undermapper';
$lang['subdir'] = 'undermappe';
$lang['and'] = 'og';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; mappen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen og alt dens indhold blev slettet.';
$lang['dirtreedeletefail'] = 'Der skete en fejl under sletning af mappen. Noget af indholdet kan v&aelig;re blevet slettet.';
$lang['singlefiledeletesuccess'] = 'Filen blev slettet';
$lang['filedeletesuccess'] = 'blev slettet.';
$lang['singlefiledeletefail'] = 'Sletning af filen mislykkedes';
$lang['filedeletefail'] = 'blev ikke slettet pga. en fejl.';
$lang['singledirdeletesuccess'] = 'Mappen blev slettet';
$lang['singledirdeletefail'] = 'Der skete en fejl ved sletning af mappen.';
$lang['deleteselected'] = 'Slet de valgte filer';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; de valgte filer skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletning af filer blev afbrudt';
$lang['recursetext'] = 'Medtag undermapper';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['moveselected'] = 'Flyt de valgte filer';
$lang['copyselected'] = 'Kopi&eacute;r de valgte filer';
$lang['selecttargetdir'] = 'V&aelig;lg hvor der skal flyttes/kopieres til';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopieret til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['rename'] = 'Omd&oslash;b';
$lang['newname'] = 'Nyt navn:';
$lang['renamesuccess'] = 'Filen blev omd&oslash;bt';
$lang['renamefailure'] = 'Omd&oslash;bning af filen fejlede';
$lang['renamecancelled'] = 'Omd&oslash;bning afbrudt';
$lang['owner'] = 'Ejer';
$lang['group'] = 'Gruppe';
$lang['others'] = 'Andre';
$lang['newpermissions'] = 'Nye tilladelser:';
$lang['setpermissions'] = 'S&aelig;t tilladelser';
$lang['permissionstyle'] = 'Tilladelses-stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Hurtig chmod (som 777)';
$lang['chmod'] = 'Skift tilladelser';
$lang['chmodselected'] = 'Skift tilladelser p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fik nye tilladelser';
$lang['chmodfailure'] = '&AElig;ndring af filens tilladelser fejlede';
$lang['chmodcancelled'] = '&AElig;ndring af tilladelser blev afbrudt';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, someof it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'Mappen fik nye tilladelser';
$lang['dirchmodfailure'] = '&AElig;ndring af mappens tilladelser fejlede';
$lang['dirnotemptyconfirm'] = 'Mappen er ikke tom! Er du sikker p&aring; du vil slette den og alt dens indhold?';
$lang['dirtreedeletecancelled'] = 'Sletning af mappen blev afbrudt';
$lang['imsure'] = 'Jeg er sikker';
$lang['cancel'] = 'Fortryd';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Upload ny fil:';
$lang['unpackafterupload'] = 'Fors&oslash;g udpakning efter upload (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'blev korrekt uploadet';
$lang['uploadfail'] = 'blev ikke korrekt upload&#039;et pga. en fejl';
$lang['unpacksuccess'] = 'blev korrekt udpakket';
$lang['unpackfail'] = 'blev ikke korrekt udpakket pga.:';
$lang['packfileopenfail'] = 'Kunne ikke udpakke filen (ikke-underst&oslash;ttet format?)';
$lang['packfilewritefail'] = 'Kunne ikke f&aring; lov til at skrive til filen &amp;s';
$lang['currentpath'] = 'Nuv&aelig;rende sti:';
$lang['newdirname'] = 'Opret ny mappe:';
$lang['newdirsuccess'] = 'Mappen blev oprettet';
$lang['newdirfail'] = 'Det skete en fejl ved oprettelse af mappen';
$lang['invalidnewdir'] = 'Navnet p&aring; den nye mappe kan ikke indholde tegn som /, \ og &#039;..&#039; ';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Ikon st&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'Tusinde-punkt';
$lang['none'] = 'Ingen';
$lang['space'] = 'mellemrum';
$lang['showthumbnails'] = 'Vis billedeksempler';
$lang['showthumbnailshelp'] = 'Hvis dette er sl&aring;et til vises billedeksempler hvis de eksisterer og eksempel-filen skjules. Hvis sl&aring;et fra vises alle filer.';
$lang['uploadfilesto'] = 'Upload&#039;er filer til:';
$lang['uploadview'] = 'Upload filer';
$lang['uploadboxes'] = 'Antal upload-bokse';
$lang['nothinguploaded'] = 'Intet blev upload&#039;et';
$lang['unsupportedarchive'] = 'Ikke-underst&oslash;ttet arkiv-format';
$lang['uploadmethod'] = 'Upload metode';
$lang['uploaderstandard'] = 'Standard html input-metode (tillader udpakning)';
$lang['enableadvanced'] = 'Sl&aring; avanceret modus til? (hvis tilladt)';
$lang['advancedhelp'] = 'Giver dig adgang til hele cmsms-filsystemet, ikke bare /upload/ (hvis tilladelsen er sl&aring;et til)';
$lang['showhiddenfileshelp'] = 'Virker kun med avanceret modus sl&aring;et til';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekr&aelig;ft sletning af en enkelt fil?';
$lang['settingssaved'] = 'Indstillinger blev gemt';
$lang['help'] = '		<h3>Hvad g&oslash;r dette modul?</h3>
		<p>Dette modul giver adgang til basale funktioner til filh&aring;ndtering</p>
		<h3>Hvordan bruger jeg det?</h3>
		<p>V&aelig;lg det fra indholds-menuen</p>';
$lang['utma'] = '156861353.2039886585.1231713618.1242056389.1242338820.32';
$lang['utmz'] = '156861353.1242056389.31.7.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
